@@ -30,6 +30,10 @@ fi
 cat > release_notes.md << EOF
 This is the latest set of releases that you can use with your agent of choice. We recommend using the SpecifyPlus CLI to scaffold your projects, however you can download these independently and manage them yourself.
 
+## Changelog
+
+$COMMITS
+
 EOF
 
 echo "Generated release notes:"
